"""\
PEP INFO

PEP 281 -- Loop Counter Iteration with range and xrange
Status: Rejected
Created: 2002-02-11

MODULE INFO

This module changes range into a function that runs like specified in PEP 281.

REFERENCES

PEP 281: <https://peps.python.org/pep-0281/>
"""
PEP = 281
import builtins as _b

class _range_meta(type):
    def __subclasscheck__(cls, c: type) -> bool:
        return issubclass(c, _b.range)
    def __instancecheck__(cls, i) -> bool:
        return isinstance(i, _b.range)
    def __getattr__(cls, attr: str):
        return getattr(_b.range, attr)
    def __and__(cls: type, cls1) -> type:
        try:
            from . import pep212, pep204
        except ImportError:
            import pep212, pep204
        if cls1 == pep204:
            return NotImplemented
        if cls1 != pep212.indices:
            raise TypeError(f'Cannot combine {cls!r} and {cls1!r}')
        return cls1
    __rand__ = __and__
class range(metaclass=_range_meta):
    """Same as `builtins.range`, but sequence arguments are converted to their lengths."""
    def __new__(cls, *args):
        a = []
        for arg in args:
            try:
                a.append(arg.__index__())
            except (AttributeError, ValueError):
                try:
                    a.append(len(arg))
                except (TypeError, ValueError):
                    raise TypeError(f'TypeError: {type(arg).__name__!r} object '
                                    'cannot be interpreted '
                                    'as an integer or sequence') from None
        return _b.range.__new__(_b.range, *a)
    __init__ = None



"""\
This is where combined versions are stored.
"""
import builtins as _b
from functools import wraps as _w
def _cb(*combines):
    # Sets the `combines` atrribute.
    @_w(_cb)
    def _i(func):
        func.combines = frozenset(combines)
        return func
    return _i

# PEPs 349 & 3140
try:
    from pep3140 import _str
except ImportError:
    from . import pep3140 as _p
    _str = _p._str
class _str_meta(type):
    def __subclasscheck__(cls, c: type) -> bool:
        return issubclass(c, _b.str)
    def __instancecheck__(cls, i) -> bool:
        return isinstance(i, _b.str)
@_cb(349, 3140)
class str(_b.str, metaclass=_str_meta):
    """Combination of PEPs 349 & 3140.
    See pep349.str and pep3140.str for more information.
    """  # "See ..." temporary; replace it later.
    def __new__(cls, arg, *args, **kwargs):
        if (not args) and (not kwargs):
            if not isinstance(arg, (_b.str, bytes)):
                arg = _str(arg)
                if not isinstance(arg, (_b.str, bytes)):
                    raise TypeError(f'__str__ returned non-string or non-{bytes.__name__} '
                                    f'(type {type(arg).__name__})')
        if isinstance(arg, _b.str) or args or kwargs:
            return _b.str.__new__(_b.str, arg, *args, **kwargs)
        else:
            return _b.bytes.__new__(_b.bytes, arg, *args, **kwargs)
    __init__ = None

# PEPs 204 & 281
try:
    from pep281 import range as _r
except ImportError:
    from . import pep281 as _p
    _r = _p.range
class _rliteral:
    """Combination of PEPs 204 & 281.
    Use rliteral[a:b:c] to get range(a, b, c), rliteral[a] to get range(a).
    """
    def __getitem__(self, x) -> range:
        if isinstance(x, slice):
            start, stop, step = x.start, x.stop, x.step
            if stop is None:
                raise ValueError('Stop is required')
            if start is None:
                start = 0
            if step is None:
                step = 1
            return _r(start, stop, step)
        return _r(x)
    def __repr__(self):
        return "<class 'combined.rliteral'>"
rliteral = _cb(204, 281)(_rliteral())

# PEPs 212 & 281
try:
    from pep212 import indices
except ImportError:
    from . import pep212 as _p
    indices =  _p.indices
indices = _cb(212, 281)(indices)



"""\
PEP INFO

PEP 335 -- Overloadable Boolean Operators
Status: Rejected
Created: 2004-08-29

MODULE INFO

This module implements the and_/AND, or_/OR & not_/NOT functions that
check for the dunder methods specified in PEP 335. NeedOtherOperand is
also implemented. These functions also have "plain" versions in the
`plain` namespace that does not do short-circuiting.

REFERENCES

PEP 335: <https://peps.python.org/pep-0335/>
"""
PEP = 335

import warnings as _w
class _singleton(type):
    # NeedOtherOperand is a singleton
    _instances = {}
    def __call__(cls, *args, **kwargs):
        if cls not in cls._instances:
            cls._instances[cls] = super().__call__(*args, **kwargs)
        return cls._instances[cls]
class NeedOtherOperandType(metaclass=_singleton):
    """Returned by dunder methods when the other side is needed."""
    def __repr__(self) -> str:
        return 'NeedOtherOperand'
    __str__ = __repr__
    def __hash__(self):
        return hash(id(self))
NeedOtherOperand = NeedOtherOperandType()
_notimplemented_warning_message = ('NotImplemented should not be used '
                                   'in a boolean context. Did you mean to '
                                   'return NeedOtherOperand?')
def NOT(a) -> bool:
    """Equal to `not a`, but checks for `a.__not__()` first."""
    a_not = getattr(a, '__not__', None)
    if a_not is None:
        return not a
    a_return = a_not()
    if a_return is NeedOtherOperand or a_return is NotImplemented:
        return not a
    return bool(a_return)
not_ = NOT
class plain:
    """Namespace where versions that do not do short circuiting,
    i.e. don't call `__and1__`, exist.
    """
    def __init__(self):
        raise Exception('plain cannot be initialized')
    @staticmethod
    def AND(a, b):
        """`a and b`, but:
        - a.__and2__(b) is first checked. If a value returned, return it.
        - If a.__and2__(b) does not exist or returns NeedOtherOperand, check for b.__rand2__(a).
        - If b.__rand2__(a) does not exist or returns NeedOtherOperand, return `a and b`.
        """
        a_and = getattr(a, '__and2__', None)
        if a_and is not None:
            a_return = a_and(b)
            if a_return is NotImplemented:
                _w.warn(_notimplemented_warning_message,
                        PendingDeprecationWarning, 2)
            if a_return is not NeedOtherOperand:
                return a_return
        b_rand = getattr(b, '__rand2__', None)
        if b_rand is not None:
            b_return = b_rand(a)
            if b_return is NotImplemented:
                _w.warn(_notimplemented_warning_message,
                        PendingDeprecationWarning, 2)
            if b_return is not NeedOtherOperand:
                return b_return
        with _w.catch_warnings():
            return a and b
    and_ = AND
    @staticmethod
    def OR(a, b):
        """`a or b`, but:
        - a.__or2__(b) is first checked. If a value returned, return it.
        - If a.__or2__(b) does not exist or returns NeedOtherOperand, check for b.__ror2__(a).
        - If b.__ror2__(a) does not exist or returns NeedOtherOperand, return `a and b`.
        """
        a_or = getattr(a, '__or2__', None)
        if a_or is not None:
            a_return = a_or(b)
            if a_return is NotImplemented:
                #
                _w.warn(_notimplemented_warning_message,
                        PendingDeprecationWarning, 2)
            if a_return is not NeedOtherOperand:
                return a_return
        b_ror = getattr(b, '__ror2__', None)
        if b_ror is not None:
            b_return = b_ror(a)
            if b_return is NotImplemented:
                _w.warn(_notimplemented_warning_message,
                        PendingDeprecationWarning, 2)
            if b_return is not NeedOtherOperand:
                return a_return
        with _w.catch_warnings():
            return a or b
    or_ = OR
    NOT = not_ = staticmethod(NOT)
def AND(a, b):
    """`a and b`, but:
    - a.__and1__() is first checked. If a value returned, return it.
    - If a.__and1__() does not exist or returns NeedOtherOperand, check for a.__and2__(b).
    - If a.__and2__(b) does not exist or returns NeedOtherOperand, check for b.__rand2__(a).
    - If b.__rand2__(a) does not exist or returns NeedOtherOperand, return the classic `a and b`.
    """
    a_and = getattr(a, '__and1__', None)
    if a_and is None:
        return plain.AND(a, b)
    a_return = a_and()
    if a_return is NeedOtherOperand:
        return plain.AND(a, b)
    if a_return is NotImplemented:
        _w.warn(_notimplemented_warning_message,
                PendingDeprecationWarning, 2)
    return a_return
and_ = AND
def OR(a, b):
    """`a or b`, but:
    - a.__or__() is first checked. If a value returned, return it.
    - If a.__or1__() does not exist or returns NeedOtherOperand, check for a.__or2__(b).
    - If a.__or2__(b) does not exist or returns NeedOtherOperand, check for b.__ror2__(a).
    - If b.__ror2__(a) does not exist or returns NeedOtherOperand, return the classic `a or b`.
    """
    a_or = getattr(a, '__or1__', None)
    if a_or is None:
        return plain.OR(a, b)
    a_return = a_or()
    if a_return is NeedOtherOperand:
        return plain.OR(a, b)
    if a_return is NotImplemented:
        _w.warn(_notimplemented_warning_message,
                PendingDeprecationWarning, 2)
    return a_return
or_ = OR



__version__ = '1.0.0dev7'
import importlib as _imp
import warnings as _w
from collections import namedtuple as _nt
from itertools import chain as _chain
from functools import lru_cache as _lc
# Typing
from typing import Generator as _Gen, Optional as _O
from types import ModuleType as _Module

SUPPORTED = frozenset((204, 211, 212, 259,
                       265, 276, 281, 294,
                       303, 313, 326, 335,
                       336, 349, 351, 416,
                       535, 559, 754, 3140))
# ↑ Not automatic because it's too slow

_pep_imported = {}
def pep(n: int, *ns, allow_empty: bool = False) -> _Module:
    """Return a pep module based on the pep number(s).

    If a single number is provided, the corresponding module is returned.

    If several numbers are provided, a namespace containing the combined objects is returned;
    if there are none, an error is raised unless `allow_empty=True`, where an empty
    namespace is returned.
    """
    if not ns:
        if n in _pep_imported:
            return _pep_imported[n]
        if (not isinstance(n, int)) or n < 0 or n > 9999:
            raise ValueError(f'Invalid PEP number {n!r}')
        try:
            try:
                md =  _imp.import_module(f'..pep{n}', 'rejected_peps.subpkg')
            except ImportError:
                md = _imp.import_module(f'pep{n}')
            _pep_imported[n] = md
            return md
        except ImportError:
            raise ValueError(f'PEP {n!r} not supported') from None
    else:
        try:
            from . import combined
        except ImportError:
            import combined
        combined = _imp.reload(combined)
        ns = frozenset((n, *ns))
        mp = map(str, sorted(ns))
        m = _Module(f'pep' + '_'.join(mp))  # Use := after 3.7 dropped
        v, f = vars(combined), False
        for i in v:
            try:
                if not (getattr(v[i], 'combines') - ns):  # If .combines is a subset of ns
                    setattr(m, i, v[i])
                    f = True
            except AttributeError:
                pass
        if not (f or allow_empty):
            raise ValueError('PEPs ' + ', '.join(mp[:-1]) + f' and {mp[-1]} are not supported'
                             'or cannot be combined')
        return m

@_lc(maxsize=64, typed=True)
def search(*s, strict: bool = False) -> _Gen:
    """Return the numbers of PEPs that have a title or registered name matching *all* the keywords.

    If `strict=True` (default False), the search is case sensitive.
    """
    global SUPPORTED
    if not s:
        return  # Empty
    if any((not isinstance(i, str)) for i in s):
        raise TypeError('Invalid argument(s)')
    yielded = set()
    func = ((lambda n: n) if strict else str.casefold)
    for pep in sorted(SUPPORTED):
        t = info(pep).title
        if all((func(x) in func(t)) for x in s):
            yield pep
            yielded.add(pep)
    for k in s:
        if k in _reg and _reg[k] not in yielded:
            yield _reg[k]

@_lc(maxsize=64, typed=True)
def _search_any(*s, strict: bool = False) -> _Gen:
    """Return the numbers of PEPs that have a title or registered name matching
    *any* of the keywords.

    If `strict=True` (default False), the search is case sensitive.
    """
    yielded = set()
    for i in _chain.from_iterable(search(x, strict=strict) for x in s):
        if i not in yielded:
            yield i
            yielded.add(i)
search.any = _search_any

@_lc(maxsize=64, typed=True)
def _search_one(*s, strict: bool = True) -> _O[int]:
    """Return the number of the PEP that has a title or registered name matching
    *all* the keywords.
    If zero or several PEPs are found, an error is raised.
    If `strict=True` (default False), the search is case sensitive.
    """
    global SUPPORTED
    if not s:
        return None
    func = ((lambda n: n) if strict else str.casefold)
    xs = []
    for pep in sorted(SUPPORTED):
        t = info(pep).title
        j = 0
        for x in s:
            try:
                j += (func(x) in t.lower() or
                      func(x) in func(t) or
                      func(x) in t.upper() or
                      _reg.get(func(x), -1) == pep)
            except TypeError:
                message = ["args must be type 'str', ",
                           f"not {type(x).__name__!r}"]
                if isinstance(x, bool):
                    message.append(f'. Did you mean strict={x!r}?')
                raise TypeError(''.join(message)) from None
        if j == len(s):
            if not strict:
                return pep
            xs.append(pep)
    if not strict:
        return None
    if xs[1:]:
        raise ValueError(f'More than 1 match: {", ".join(map(str, xs))} ({len(xs)})')
    if not xs:
        raise ValueError(f'No match found')
    return xs[0]
search.one = _search_one

@_lc(maxsize=64, typed=True)
def _search_one_any(*s, strict: bool = True) -> _O[int]:
    """Return the number of the PEP that has a title or registered name matching
    *any* of the keywords.
    If zero or several PEPs are found, an error is raised.
    If `strict=True` (default False), the search is case sensitive.
    """
    global SUPPORTED
    if not s:
        return None
    func = ((lambda n: n) if strict else str.lower)
    xs = []
    for pep in sorted(SUPPORTED):
        t = info(pep).title
        for x in s:
            try:
                cond = (func(x) in t.lower() or
                        func(x) in func(t) or
                        func(x) in t.upper() or
                        _reg.get(func(x), -1) == pep)
                if cond:
                    break
            except TypeError:
                message = ["args must be type 'str', ",
                           f"not {type(x).__name__!r}"]
                if isinstance(x, bool):
                    message.append(f'. Did you mean strict={x!r}?')
                raise TypeError(''.join(message)) from None
        else:
            continue
        if not strict:
            return pep
        xs.append(pep)
    if not strict:
        return None
    if xs[1:]:
        raise ValueError(f'More than 1 match: {", ".join(map(str, xs))} ({len(xs)})')
    if not xs:
        raise ValueError(f'No match found')
    return xs[0]
search.one.any = _search_one_any

@_lc(maxsize=64, typed=True)
def get(*s) -> _Module:
    """Return the module of the PEP that has a title matching *all* the keyword(s).
    If zero or several PEPs are found, an error is raised.
    If `strict=True` (default False), the search is case-sensitive.
    """
    return pep(search.one(*s))
@_lc(maxsize=64, typed=True)
def _get_any(*s) -> _Module:
    """Return the module of the PEP that has a title matching *any* of the keyword(s).
    If zero or several PEPs are found, an error is raised.
    If `strict=True` (default False), the search is case-sensitive.
    """
    return pep(search.one.any(*s))
get.any = _get_any

del _search_any
del _search_one
del _search_one_any
del _get_any

_reg = {}
def register(n: int, name: str):
    """Register a name for a PEP number.

    After registering, you can use `rejected_peps.name` or specify it in `search` etc.
    to get the module.
    """
    if __debug__:
        # Specify -O or -OO to improve speed.
        try:
            info(n)
        except (ValueError, UnavailableError):
            raise ValueError(f'Invalid PEP num {n!r}') from None
    if name in _reg and _reg[name] != n:
        raise KeyError(f'Ambiguous keyword {name!r} => {_reg[name]!r} or {n!r}')
    if ((name.startswith('pep') and name[3:].isdigit() and int(name[3:]) in SUPPORTED)
        or name in {'combined', 'test'}):
        _w.warn(f'Name {name!r} conflicts with module {name}; .{name} will return the latter',
                RuntimeWarning, stacklevel=2)
    _reg[name] = n
def unregister(name: str):
    """Unregister a name."""
    del _reg[name]
def clear_register():
    """Clear all registered names."""
    _reg.clear()

class UnavailableError(LookupError, NotImplementedError):
    pass
pepinfo = _nt('pepinfo', ('number', 'title', 'status', 'creation', 'url'))
@_lc(maxsize=32, typed=True)
def info(n: int) -> pepinfo:
    """Return the info of a PEP.

    If the info is unavailable, an UnavailableError is raised.
    """
    doc = getattr(pep(n), '__doc__', '').splitlines()
    if not doc[3:]:
        raise UnavailableError(f'Info of PEP {n!r} unavailable')
    return pepinfo(number=n,
                   title=doc[2].split(' -- ')[1],
                   status=doc[3].lstrip('Status: '),
                   creation=doc[4].lstrip('Created: '),
                   url=f'https://peps.python.org/pep-{n:0>4}/')

def __getattr__(name: str):
    if name.startswith('pep'):
        try:
            p = pep(int(name[3:]))
        except (TypeError, ValueError):
            pass
        else:
            return p
    try:
        p = pep(_reg[name])
    except Exception:  # nosec B110
        pass
    else:
        return p
    # Suggestions
    if name.upper() == 'SUPPORTED':
        raise AttributeError(f'module {__name__!r} has no attribute {name!r}. '
                             "Did you mean: 'SUPPORTED'?")
    if name.lower().startswith('info'):
        raise AttributeError(f'module {__name__!r} has no attribute {name!r}. '
                             "Did you mean: 'info'?")
    raise AttributeError(f'module {__name__!r} has no attribute {name!r}')
def __dir__() -> list:
    return sorted(set(globals().keys()) | {f'pep{n}' for n in SUPPORTED})



"""\
PEP INFO

PEP 349 -- Allow str() to return unicode strings
Status: Rejected
Created: 2005-08-02

MODULE INFO

This module changes str() to allow returning **bytes**.
Since all strings are unicode starting from Python 3,
the title is changed. Note that three argument form is
still implemented as normal.

REFERENCES

PEP 349: <https://peps.python.org/pep-0349/>
"""
PEP = 349
import builtins as _b

bytes = _b.bytes
class _str_meta(type):
    def __subclasscheck__(cls, c: type) -> bool:
        return issubclass(c, _b.str)
    def __instancecheck__(cls, i) -> bool:
        return isinstance(i, _b.str)
    def __and__(cls: type, cls2: type) -> type:
        try:
            from . import pep3140
        except ImportError:
            import pep3140
        if cls2 == pep3140.str:
            try:
                from . import combined
            except ImportError:
                import combined
            return combined.str
        raise TypeError(f'Cannot combine {cls!r} and {cls2!r}')
    __rand__ = __and__
class str(_b.str, metaclass=_str_meta):
    """Same as `builtins.str`, but a `bytes` is returned if `__str__` returns bytes.
    The str(bytes_or_buffer, encoding[, errors]) form is unchanged.
    """
    def __new__(cls, arg, *args, **kwargs):
        if (not args) and (not kwargs):
            if not isinstance(arg, (_b.str, bytes)):
                arg = arg.__str__()
                if not isinstance(arg, (_b.str, bytes)):
                    raise TypeError(f'__str__ returned non-string or non-{bytes.__name__} '
                                    f'(type {type(arg).__name__})')
        if isinstance(arg, _b.str) or args or kwargs:
            return _b.str.__new__(_b.str, arg, *args, **kwargs)
        else:
            return _b.bytes.__new__(_b.bytes, arg, *args, **kwargs)
    __init__ = None



"""\
PEP INFO

PEP 211 -- Adding A New Outer Product Operator
Status: Rejected
Created: 2000-07-15

MODULE INFO

This module implements a wrapper that enables the @ operator
to mean itertools.product. Call the wrapper to get the original object.

REFERENCES

PEP 211: <https://peps.python.org/pep-0211/>
"""
PEP = 211

from itertools import product
class wrapper:
    """Wrap an object to let it allow @ => product. Call it to get the original object.
    For example:
    >>> list(wrapper([2, 3]) @ (5, 6))
    [(2, 5), (2, 6), (3, 5), (3, 6)]
    >>> list([1] @ wrapper({4, 5}))
    [(1, 4), (1, 5)]
    >>> wrapper([1, 2])()
    [1, 2]
    """
    def __init__(self, obj):
        self._obj = obj
    def __repr__(self):
        return f'{self.__class__.__name__}({self._obj!r})'
    def __matmul__(self, other) -> product:
        try:
            return product(self(), getattr(other, '_obj', other))
        except TypeError:
            try:
                return product(self(), repeat=other)
            except TypeError:
                return NotImplemented
    def __rmatmul__(self, other) -> product:
        try:
            return product(getattr(other, '_obj', other), self())
        except TypeError:
            return NotImplemented
    def __call__(self):
        return self._obj
    @property
    def __wrapped__(self):
        return self._obj



"""\
PEP INFO

PEP 351 -- The freeze protocol
Status: Rejected
Created: 2005-04-14

MODULE INFO

This module implements the freeze() function in PEP 351. An allow_frozendict
parameter is added. If true (false by default), dicts, OrderedDicts
and defaultdicts return the manual implementation of frozendict in PEP 416
if possible.

REFERENCES

PEP 351: <https://peps.python.org/pep-0351/>
Related:
PEP 416: <https://peps.python.org/pep-0416/>
"""
PEP = 351

from types import MappingProxyType as _MPT
from collections.abc import Mapping as _M, Sequence as _S
def freeze(obj, *, allow_frozendict: bool = False):
    """Freeze `obj`.
    If `obj` is hashable, return it untouched.
    If not, what's returned depends on its type:
    - If it's a set, return frozenset(obj).
    - If it's a sequence, return tuple(obj).
    - If it's a mapping:
        - If `allow_frozendict` is true and pep416 is available, return pep416.frozendict(obj);
        - If not, return MappingProxyType(obj).
    - If it has __freeze__, return obj.__freeze__.
    - Else raise a TypeError.
    """
    global _pep416
    try:
        hash(obj)
    except TypeError:
        # Since PEP is rejected, set, list etc. don't implement __freeze__,
        # so manual check is needed
        if isinstance(obj, set):
            return frozenset(obj)
        if isinstance(obj, _S):
            t = tuple(obj)
            return t
        if isinstance(obj, _M):
            if allow_frozendict:
                # Allow using manual PEP 416 implementation from pep416 module
                try:
                    try:
                        _pep416
                    except NameError:
                        try:
                            from . import pep416
                        except ImportError:
                            import pep416
                        _pep416 = pep416
                    d = _pep416.frozendict(obj)
                except Exception:
                    d = _MPT(obj)
            else:
                d = _MPT(obj)  # MappingProxyType by default
            return d
        # Fallback
        freezer = getattr(obj, '__freeze__', None)
        if freezer is None:
            raise TypeError(f'{type(obj).__name__!r} object is not freezable')
        return freezer()
    else:
        return obj



"""\
PEP INFO

PEP 535 -- Rich comparison chaining
Status: Deferred
Created: 2016-11-12

MODULE INFO

This module adds cmp(obj, op, obj, ..., andfunc=None) that implements rich comparison chaining.
If andfunc is not None, andfunc is used instead of and, else obj.__andfunc__ is checked;
then it falls back onto and.

REFERENCES

PEP 535: <https://peps.python.org/pep-0535/>
"""
PEP = 535
from typing import Callable as _C, Optional as _O

# Constants
LT = '<'
LE = '<='
EQ = '=='
NE = '!='
GE = '>='
GT = '>'
VALID = frozenset((LT, LE, EQ, NE, GE, GT))

# Functions
def _cmp(a, op: str, b):
    # Use match/case in 3.10+
    if not isinstance(op, str):
        raise TypeError(f'Invalid op {op!r}')
    if op == '<': return a < b
    if op == '<=': return a <= b
    if op == '==': return a == b
    if op == '!=': return a != b
    if op == '>=': return a >= b
    if op == '>': return a > b
    raise ValueError(f'Invalid op {op!r}')
def cmp(*args, and_func: _O[_C] = None):
    """Chain comparison.
    Pass arguments in the regular order, e.g. cmp(a, '<', b, '<', c[, andfunc=...]).

    If keyword argument `and_func` is not None, `and_func(x, y)` chains the comparisons,
    e.g. `and_func(a<b, b<c)`.
    If it is None, `x.__andfunc__` is checked, e.g. (a<b).__andfunc__(b<c).
    If `x.__andfunc__` does not exist, `y.__randfunc__` is checked, e.g. (b<c).__randfunc__(a<b).
    If `y.__randfunc__` does not exists, the classic `x and y` is used.
    """
    if len(args) % 2 == 0:
        raise ValueError(f'Invalid arguments ({len(args)}; should be odd)')
    obj = args[::2]
    op = args[1::2]
    b = _cmp(obj[0], op[0], obj[1])
    for i in range(1, len(obj)-1):
        c = _cmp(obj[i], op[i], obj[i+1])
        if and_func is None:
            if hasattr(b, '__andfunc__'):
                b = b.__andfunc__(c)
            elif hasattr(c, '__randfunc__'):
                b = c.__randfunc__(b)
            else:
                try:
                    b = b and c
                except Exception as e:
                    try:
                        e.add_note('Error occurred while falling back to '
                                   '{b!r} and {c!r}')
                    except AttributeError:
                        raise e from None
                    else:
                        raise e
        else:
            b = and_func(b, c)
    return b



"""\
PEP INFO

PEP 294 -- Type Names in the types Module
Status: Rejected
Created: 2002-06-19

MODULE INFO

The apply(module=types, *, rename=underscore, strict=bool) function
adds the lowercase regular version as in the PEP to
the module. If the new name is invalid (e.g. `lambda`), rename(name)
is called. If strict is True, then the new return value of rename()
and the type (should be str) will be checked. This is done in-place
so apply() returns None.
The underscore(), title() and original() functions are provided
for the rename parameter.
See the docstrings for more information.

REFERENCES

PEP 294: <https://peps.python.org/pep-0294/>
"""
PEP = 294
import keyword as _k
import threading as _t
from importlib import import_module as _im
from typing import Optional as _O, Callable as _C

def underscore(s: str) -> str:
    """Appends an underscore (_) to s."""
    if not isinstance(s, str):
        raise TypeError(f's must be str, not {type(s).__name__}')
    return f'{s}_'
title = str.title
def original(s: str) -> str:
    """Returns s."""
    if not isinstance(s, str):
        raise TypeError(f's must be str, not {type(s).__name__}')
    return s
def valid(name) -> bool:
    """True if name is an identifier & not a keyword. Note that non-str types return True."""
    if not isinstance(name, str):
        return True
    return _k.iskeyword(name) + (not name.isidentifier()) == 0

_apply_lock = _t.RLock()
def apply(module=None, *, mapfunc: _O[_C] = None, rename: _O[_C] = None,
          strict: _O[bool] = None):
    """Add the lowercase regular version as in PEP 294 to
    the module after processed by `mapfunc` (default `original`).
    If the new name is invalid (e.g. `lambda`), `rename(name)`
    is called.
    If strict is True, then the new return value of `rename(name)`
    and the type (should be str) will be checked. If `None`, true only if `rename` is `original`.
    Returns the modified module.
    """
    mapfunc = mapfunc or original
    rename = rename or underscore
    if strict is None:
        strict = rename is not original
    with _apply_lock:
        types = module or _im('types')
        for name in dir(types):
            new_name = mapfunc(name[:-4].lower())
            if name[-4:] == 'Type' and name[:-4]:
                if not valid(new_name):
                    r = rename(new_name)
                    if strict and not valid(r):
                        raise ValueError(f'Invalid name {r!r}')
                    new_name = r
                if strict and type(new_name) is not str:
                    # str subclasses aren't allowed
                    raise TypeError(f'Invalid name {new_name!r} with type '
                                    f'{type(r).__name__!r}')
                setattr(types, new_name, getattr(types, name))
        return types



"""\
PEP INFO

PEP 3140 -- str(container) should call str(item), not repr(item)
Status: Rejected
Created: 2008-05-27

MODULE INFO

This module changes str() to a function matching behavior
described in the PEP.

REFERENCES

PEP 3140: <https://peps.python.org/pep-3140/>
"""
PEP = 3140
import builtins as _b
from reprlib import recursive_repr as _rr
from collections.abc import Container as _C, Mapping as _M

@_rr()
def _str(x) -> _b.str:
    if (not isinstance(x, _C)) or isinstance(x, (_b.str, bytes)):
        xs = getattr(x, '__str__', None)
        if xs is not None:
            value = xs()
            if value is not NotImplemented:
                return value
        return x.__repr__()
    if isinstance(x, (dict, _M)):
        if type(x) is dict:  # no subclasses
            # {}
            prefix = suffix = ''
        else:
            # X({})
            ss = _b.str(x)
            try:
                si, ei = ss.index('{'), len(ss)-1-ss[::-1].index('}')
            except ValueError:
                prefix, suffix = f'{type(x).__name__}(', ')'
            else:
                prefix, suffix = ss[:si], ss[ei+1:]
        if not x:  # Empty
            return '%s{}%s' % (prefix, suffix)
        parts = [prefix, '{']
        for key, value in x.items():
            parts.extend((f'{key!s}: {value!s}', ', '))
        parts = [*parts[:-1], '}', suffix]
        return ''.join(parts)
    else:
        cls = type(x)
        prefix, suffix = {list: ('[', ']'),
                          tuple: ('(', ')'),
                          set: ('{', '}'),
                          }.get(cls, (f'{cls.__name__}([', '])'))
        parts = [prefix]
        for item in x:
            parts.extend((str(item), ', '))
        if not (isinstance(x, tuple) and len(x) == 1):
            if len(x):
                parts = parts[:-1]
        else:
            parts[-1] = ','
        return ''.join((*parts, suffix))
class _str_meta(type):
    def __subclasscheck__(cls, c: type) -> bool:
        return issubclass(c, _b.str)
    def __instancecheck__(cls, i) -> bool:
        return isinstance(i, _b.str)
class str(_b.str, metaclass=_str_meta):
    """Same as `builtins.str`, but `str` is called on sequence/mapping elements.
    The str(bytes_or_buffer, encoding[, errors]) form is unchanged.
    """
    def __new__(cls, arg, *args, **kwargs):
        if (not args) and (not kwargs):
            arg = _str(arg)
        return _b.str.__new__(_b.str, arg, *args, **kwargs)
    __init__ = None
